<template>
  <div>
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @tableRowClassName="tableRowClassName"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="255"
      :ajaxFun="ajaxFun"
      ref="deliveryDetailTable"
      :paramObj="paramObj"
    >
      <template #toolbar></template>
    </ttable>
    <!-- 弹窗, 新增 / 修改 -->
    <table-form
      v-if="addOrUpdateVisible"
      ref="addOrUpdate"
      @refreshDataList="getData"
    ></table-form>
  </div>
</template>

<script>
import {
  fetchListDeliveryDetail,
  delDeliveryDetail,
  auditDeliveryDetail,
  putInStorage
} from '@/api/warehouse/receiving'
import { addResultByReceiving } from '@/api/quality/result'
import TableForm from './delivery-detail-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import info from '../../admin/user/info'

export default {
  props: {
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    disabled: {
      type: Boolean,
      default: false
    },
    visible: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      ajaxFun: fetchListDeliveryDetail,
      // 送货清单
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: false, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'partNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '110',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          {
            minWidth: '110',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '110',
            prop: 'materialType',
            label: '零件类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'deliveryQty',
            label: '送货数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'receiveQty',
            label: '接收数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'differenceQty',
            label: '差异数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'unit',
            label: '零件单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: null,
        operator: null,
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 120,
          minWidth: 120
        }
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    TableForm,
    ttable
  },
  watch: {
    visible: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.getData()
        }
      },
      immediate: true
    },
    disabled: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.table.operator = null
          this.table.toolbar = null
        } else {
          this.table.operator = [
            {
              text: '修改',
              icon: 'el-icon-edit',
              type: 'text',
              size: 'small',
              fun: this.addOrUpdateHandle
            },
            {
              text: '删除',
              icon: 'el-icon-delete',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ]
          this.table.toolbar = [
            {
              text: '新增',
              icon: 'el-icon-plus',
              type: 'primary',
              fun: this.addOrUpdateHandle,
              disabled: this.disabled
            },
            {
              text: '核实入库',
              icon: 'el-icon-circle-check',
              type: 'primary',
              fun: this.audit,
              disabled: this.disabled
            }
          ]
        }
      },
      immediate: true
    }
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      if (this.$refs.deliveryDetailTable != undefined) {
        this.$refs.deliveryDetailTable.getDataList()
      }
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      if (!this.paramObj.receivingMainId) {
        this.$message.error('请先保存')
        return
      }
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(
          row ? row.id : row,
          this.paramObj.receivingMainId
        )
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delDeliveryDetail(row ? row.id : row)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    // 审核
    audit() {
      // 1.判断是否有差异数量
      auditDeliveryDetail(this.paramObj.receivingMainId).then((response) => {
        if (response.data.data.length > 0 && response.data.data) {
          this.$confirm('存在差异数量是否核实入库', '提示', {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            closeOnClickModal: false,
            type: 'warning'
          }).then(() => {
            putInStorage(this.paramObj.receivingMainId).then((response) => {
              this.$message.success('核实入库成功')
              this.$emit('refreshDataList')
              this.addResultByReceiving(response.data.data)
            })
          })
        } else {
          putInStorage(this.paramObj.receivingMainId).then((response) => {
            this.$message.success('核实入库成功')
            this.$emit('refreshDataList')
            this.addResultByReceiving(response.data.data)
          })
        }
      })
    },
    addResultByReceiving(stockList) {
      if (stockList) {
        addResultByReceiving(stockList).then((response) => {})
      }
    },
    // table自带事件
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    tableRowClassName(row, callback) {
      if (row.deliveryQty !== row.receiveQty) {
        callback('danger-row')
      } else {
        callback('')
      }
    }
  }
}
</script>
